API_VERSION = 'v03'

API_REQUEST_JSON_KEY = 'content'

API_RESPONSE_KEY_SUCCESS = 'success'
API_RESPONSE_KEY_MESSAGE = 'message'
API_RESPONSE_KEY_CONTENT = API_REQUEST_JSON_KEY

SERVER_ROLES = [
    'user',
    'creator',
    'admin',
    'owner',
]

COURSE_ROLES = [
    'unknown',
    'other',
    'student',
    'grader',
    'admin',
    'owner',
]
